@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -26,6 +26,7 @@ import org.apache.commons.logging.LogFactory;
 import org.apache.tools.ant.BuildEvent;
 import org.apache.tools.ant.BuildListener;
 import org.apache.tools.ant.BuildLogger;
+import org.apache.tools.ant.MagicNames;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.Task;
 import org.apache.tools.ant.UnknownElement;
@@ -61,11 +62,11 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
     /**
      * name of the category under which target events are logged
      */
-    public static final String TARGET_LOG = "org.apache.tools.ant.Target";
+    public static final String TARGET_LOG = MagicNames.ANT_CORE_PACKAGE + ".Target";
     /**
      * name of the category under which project events are logged
      */
-    public static final String PROJECT_LOG = "org.apache.tools.ant.Project";
+    public static final String PROJECT_LOG = MagicNames.ANT_CORE_PACKAGE + ".Project";
 
     /**
      * Construct the listener and make sure that a LogFactory
@@ -281,8 +282,6 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
                 }
                 break;
             case Project.MSG_VERBOSE:
-                log.debug(message);
-                break;
             case Project.MSG_DEBUG:
                 log.debug(message);
                 break;
