@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -165,7 +165,7 @@ public class EmailTask extends Task {
      * @param port The port to use.
      */
     public void setMailport(int port) {
-        this.port = Integer.valueOf(port);
+        this.port = port;
     }
 
     /**
@@ -554,7 +554,7 @@ public class EmailTask extends Task {
             // pass the params to the mailer
             mailer.setHost(host);
             if (port != null) {
-                mailer.setPort(port.intValue());
+                mailer.setPort(port);
                 mailer.setPortExplicitlySpecified(true);
             } else {
                 mailer.setPort(SMTP_PORT);
