@@ -360,8 +360,8 @@ public class Commandline implements Cloneable {
      * @param line an array of arguments to append.
      */
     public void addArguments(String[] line) {
-        for (String l : line) {
-            createArgument().setValue(l);
+        for (String argument : line) {
+            createArgument().setValue(argument);
         }
     }
 
@@ -372,7 +372,7 @@ public class Commandline implements Cloneable {
     public String[] getCommandline() {
         final List<String> commands = new LinkedList<>();
         addCommandToList(commands.listIterator());
-        return commands.toArray(new String[commands.size()]);
+        return commands.toArray(new String[0]);
     }
 
     /**
@@ -395,7 +395,7 @@ public class Commandline implements Cloneable {
     public String[] getArguments() {
         List<String> result = new ArrayList<>(arguments.size() * 2);
         addArgumentsToList(result.listIterator());
-        return result.toArray(new String[result.size()]);
+        return result.toArray(new String[0]);
     }
 
     /**
@@ -436,13 +436,13 @@ public class Commandline implements Cloneable {
      */
     public static String quoteArgument(String argument) {
         if (argument.contains("\"")) {
-            if (argument.contains("\'")) {
-                throw new BuildException("Can\'t handle single and double"
+            if (argument.contains("'")) {
+                throw new BuildException("Can't handle single and double"
                         + " quotes in same argument");
             }
             return '\'' + argument + '\'';
         }
-        if (argument.contains("\'") || argument.contains(" ")
+        if (argument.contains("'") || argument.contains(" ")
                 // WIN9x uses a bat file for executing commands
                 || (IS_WIN_9X && argument.contains(";"))) {
             return '\"' + argument + '\"';
@@ -464,11 +464,11 @@ public class Commandline implements Cloneable {
         }
         // path containing one or more elements
         final StringBuilder result = new StringBuilder();
-        for (String l : line) {
+        for (String argument : line) {
             if (result.length() > 0) {
                 result.append(' ');
             }
-            result.append(quoteArgument(l));
+            result.append(quoteArgument(argument));
         }
         return result.toString();
     }
@@ -490,7 +490,7 @@ public class Commandline implements Cloneable {
         final int inQuote = 1;
         final int inDoubleQuote = 2;
         int state = normal;
-        final StringTokenizer tok = new StringTokenizer(toProcess, "\"\' ", true);
+        final StringTokenizer tok = new StringTokenizer(toProcess, "\"' ", true);
         final ArrayList<String> result = new ArrayList<>();
         final StringBuilder current = new StringBuilder();
         boolean lastTokenHasBeenQuoted = false;
@@ -499,7 +499,7 @@ public class Commandline implements Cloneable {
             String nextTok = tok.nextToken();
             switch (state) {
             case inQuote:
-                if ("\'".equals(nextTok)) {
+                if ("'".equals(nextTok)) {
                     lastTokenHasBeenQuoted = true;
                     state = normal;
                 } else {
@@ -515,7 +515,7 @@ public class Commandline implements Cloneable {
                 }
                 break;
             default:
-                if ("\'".equals(nextTok)) {
+                if ("'".equals(nextTok)) {
                     state = inQuote;
                 } else if ("\"".equals(nextTok)) {
                     state = inDoubleQuote;
@@ -537,7 +537,7 @@ public class Commandline implements Cloneable {
         if (state == inQuote || state == inDoubleQuote) {
             throw new BuildException("unbalanced quotes in " + toProcess);
         }
-        return result.toArray(new String[result.size()]);
+        return result.toArray(new String[0]);
     }
 
     /**
@@ -648,7 +648,7 @@ public class Commandline implements Cloneable {
         if (args == null || args.length == 0) {
             return "";
         }
-        StringBuilder buf = new StringBuilder("Executing \'").append(args[0]).append("\'");
+        StringBuilder buf = new StringBuilder("Executing '").append(args[0]).append("'");
         if (args.length > 1) {
             buf.append(" with ");
             buf.append(describeArguments(args, 1));
@@ -686,7 +686,7 @@ public class Commandline implements Cloneable {
         StringBuilder buf = new StringBuilder();
         buf.append(String.format("argument%s:%n", args.length > offset ? "s" : ""));
         for (int i = offset; i < args.length; i++) {
-            buf.append(String.format("\'%s\'%n", args[i]));
+            buf.append(String.format("'%s'%n", args[i]));
         }
         buf.append(DISCLAIMER);
         return buf.toString();
