@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -458,7 +458,7 @@ public class Files extends AbstractSelectorContainer
      * @return <code>FileCollection</code>.
      */
     protected Files getRef() {
-        return (Files) getCheckedRef();
+        return getCheckedRef(Files.class);
     }
 
     private synchronized void ensureDirectoryScannerSetup() {
@@ -481,7 +481,7 @@ public class Files extends AbstractSelectorContainer
         String[] includePatterns = ps.getIncludePatterns(getProject());
         String[] excludePatterns = ps.getExcludePatterns(getProject());
         return (includePatterns != null && includePatterns.length > 0)
-            || (includePatterns != null && excludePatterns.length > 0);
+            || (excludePatterns != null && excludePatterns.length > 0);
     }
 
 }
