@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -64,9 +64,9 @@ public final class SplitClassLoader extends AntClassLoader {
 
     private boolean isSplit(String classname) {
         String simplename = classname.substring(classname.lastIndexOf('.') + 1);
-        for (int i = 0; i < splitClasses.length; i++) {
-            if (simplename.equals(splitClasses[i])
-                || simplename.startsWith(splitClasses[i] + '$')) {
+        for (String splitClass : splitClasses) {
+            if (simplename.equals(splitClass)
+                    || simplename.startsWith(splitClass + '$')) {
                 return true;
             }
         }
