@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -115,16 +115,11 @@ public class DependencyVisitor extends EmptyVisitor {
                     // is upper case ascii. so according to the spec it's an inner class
                     classname = classname.substring(0, index) + "$"
                         + classname.substring(index + 1);
-                    addClass(classname);
-                } else {
-                    // Add the class in dotted notation 'com.company.Class'
-                    addClass(classname);
                 }
                 // CheckStyle:MagicNumber ON
-            } else {
-                // Add a class with no package 'Class'
-                addClass(classname);
             }
+            // Add the class, with or without the package name
+            addClass(classname);
         }
     }
 
