@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -26,6 +26,7 @@ import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.nio.file.Files;
 
 /**
  * Base class for the uuencode/decode test tasks.
@@ -54,8 +55,8 @@ abstract public class BaseTask extends Task {
         OutputStream outputStream = null;
         try {
             inputStream = new BufferedInputStream(
-                new FileInputStream(getInFile()));
-            outputStream = new FileOutputStream(getOutFile());
+                Files.newInputStream(getInFile().toPath()));
+            outputStream = Files.newOutputStream(getOutFile().toPath());
             doit(inputStream, outputStream);
         } catch (Exception ex) {
             throw new BuildException(ex);
