@@ -92,7 +92,7 @@ public class ExecutorTest implements BuildListener  {
 
     private Project getProject(String e, boolean f, boolean k) {
         Project p = buildRule.getProject();
-        p.setNewProperty("ant.executor.class", e);
+        p.setNewProperty(MagicNames.ANT_EXECUTOR_CLASSNAME, e);
         p.setKeepGoingMode(k);
         if (f) {
             p.setNewProperty("failfoo", "foo");
