@@ -21,13 +21,13 @@ import junit.framework.TestCase;
 
 public class MultilineAsserts extends TestCase {
     public void testFoo() {
-        assertTrue("testFoo \nmessed up", false);
+        fail("testFoo \nmessed up");
     }
     public void testBar() {
         assertTrue("testBar \ndidn't work", true);
     }
     public void testFee() {
-        assertTrue("testFee \ncrashed", false);
+        fail("testFee \ncrashed");
     }
     public void testFie() {
         assertTrue("testFie \nbroke", true);
